@@ -3,14 +3,13 @@
  */
 package org.gcube.common.storagehubwrapper.server.tohl;
 
-import java.io.IOException;
 import java.io.InputStream;
 import java.net.URL;
 import java.util.List;
 import java.util.Map;
 
 import org.gcube.common.storagehub.model.items.Item;
-import org.gcube.common.storagehub.model.types.GenericItemType;
+import org.gcube.common.storagehub.model.items.nodes.accounting.AccountEntry;
 import org.gcube.common.storagehubwrapper.shared.ACLType;
 import org.gcube.common.storagehubwrapper.shared.tohl.WorkspaceFolder;
 import org.gcube.common.storagehubwrapper.shared.tohl.WorkspaceItem;
@@ -25,7 +24,8 @@ import org.gcube.common.storagehubwrapper.shared.tohl.exceptions.WrongDestinatio
 import org.gcube.common.storagehubwrapper.shared.tohl.exceptions.WrongItemTypeException;
 import org.gcube.common.storagehubwrapper.shared.tohl.impl.WorkspaceFileVersion;
 import org.gcube.common.storagehubwrapper.shared.tohl.items.ItemStreamDescriptor;
-import org.gcube.common.storagehubwrapper.shared.tohl.items.URLFileItem;
+import org.gcube.common.storagehubwrapper.shared.tohl.items.PropertyMap;
+import org.gcube.common.storagehubwrapper.shared.tohl.items.URLItem;
 
 
 
@@ -314,16 +314,6 @@ public interface Workspace{
 	public ItemStreamDescriptor getThumbnailData(String itemId) throws Exception;
 
 
-	/**
-	 * Mark as public.
-	 *
-	 * @param itemId the item id
-	 * @param isPublic the is public
-	 * @return the boolean
-	 */
-	public Boolean markAsPublic(String itemId, boolean isPublic);
-
-
 	/**
 	 * Gets the metadata.
 	 *
@@ -332,187 +322,79 @@ public interface Workspace{
 	 * @throws Exception the exception
 	 */
 	public Map<String, Object> getMetadata(String itemId) throws Exception;
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+	
+	
 	/**
-	 * Create a new External URL into a folder.
+	 * Get the disk usage of a worskpace.
 	 *
-	 * @param name the external URL name.
-	 * @param description the external URL description.
-	 * @param url the external URL value.
-	 * @param destinationFolderId the destination folder.
-	 * @return the new external URL.
-	 * @throws InsufficientPrivilegesException if the user don't have sufficient privileges to perform this operation.
-	 * @throws WorkspaceFolderNotFoundException if the destination folder has not been found.
-	 * @throws InternalErrorException if an internal error occurs.
-	 * @throws ItemAlreadyExistException if a folder item with same name already exist.
-	 * @throws WrongDestinationException if the destination type is not a folder.
-	 * @throws IOException Signals that an I/O exception has occurred.
+	 * @return the disk usage
+	 * @throws Exception the exception
 	 */
-	public URLFileItem createExternalUrl(String name, String description, String url, String destinationFolderId) throws InsufficientPrivilegesException, WorkspaceFolderNotFoundException, InternalErrorException, ItemAlreadyExistException, WrongDestinationException, IOException;
+	public long getDiskUsage() throws Exception;
 
 	/**
-	 * Add a Bookmark.
+	 * Get the total number of items in a workspace.
+	 *
+	 * @return the numer of total Items
+	 * @throws Exception the exception
+	 */
+	public long getTotalItems() throws Exception;
+
+
+	/**
+	 * Gets the accounting.
+	 *
+	 * @param itemId the item id
+	 * @return the accounting
+	 * @throws Exception the exception
+	 */
+	public List<AccountEntry> getAccounting(String itemId) throws Exception;
+	
+	
+	/**
+	 * Gets the gcube item properties.
+	 *
+	 * @param gcubeItemId the gcube item id
+	 * @return the gcube item properties
+	 * @throws Exception the exception
+	 */
+	public PropertyMap getGcubeItemProperties(String gcubeItemId) throws Exception;
+
+
+	/**
+	 * Update metadata.
+	 *
+	 * @param itemId the item id
+	 * @param mapObjs the map objs
+	 * @throws Exception the exception
+	 */
+	public void updateMetadata(String itemId, Map<String,Object> mapObjs) throws Exception;
+
+	
+	/**
+	 * Creates the URL.
 	 *
 	 * @param name the name
 	 * @param description the description
 	 * @param url the url
-	 * @param destinationfolderId the destinationfolder id
-	 * @return the external url
-	 * @throws InsufficientPrivilegesException the insufficient privileges exception
-	 * @throws InternalErrorException the internal error exception
-	 * @throws ItemAlreadyExistException the item already exist exception
-	 * @throws WrongDestinationException the wrong destination exception
-	 * @throws WorkspaceFolderNotFoundException the workspace folder not found exception
-	 * @throws IOException Signals that an I/O exception has occurred.
-	 */
-	/**
-	 * Create a new External URL into a folder.
-	 * @param name the external URL name.
-	 * @param description the external URL description.
-	 * @param url the external URL.
-	 * @param destinationfolderId the destination folder.
-	 * @return the new external URL.
-	 * @throws InsufficientPrivilegesException if the user don't have sufficient privileges to perform this operation.
-	 * @throws WorkspaceFolderNotFoundException if the destination folder has not been found.
-	 * @throws InternalErrorException if an internal error occurs.
-	 * @throws ItemAlreadyExistException if a folder item with same name already exist.
-	 * @throws WrongDestinationException if the destination type is not a folder.
-	 * @throws IOException
-	 */
-	public URLFileItem createExternalUrl(String name, String description, InputStream url, String destinationfolderId) throws InsufficientPrivilegesException, InternalErrorException, ItemAlreadyExistException, WrongDestinationException, WorkspaceFolderNotFoundException, IOException;
-
-
-	/**
-	 * Delete item.
-	 *
-	 * @param itemId the item id
-	 * @throws ItemNotFoundException the item not found exception
-	 * @throws InternalErrorException the internal error exception
-	 * @throws InsufficientPrivilegesException the insufficient privileges exception
-	 * @throws Exception the exception
-	 */
-	public void deleteItem(String itemId) throws ItemNotFoundException, InternalErrorException, InsufficientPrivilegesException, Exception;
-
-
-	/**
-	 * Move item.
-	 *
-	 * @param itemId the item id
 	 * @param destinationFolderId the destination folder id
-	 * @return the workspace item
-	 * @throws ItemNotFoundException the item not found exception
-	 * @throws WrongDestinationException the wrong destination exception
-	 * @throws InsufficientPrivilegesException the insufficient privileges exception
-	 * @throws InternalErrorException the internal error exception
-	 * @throws ItemAlreadyExistException the item already exist exception
-	 * @throws WorkspaceFolderNotFoundException the workspace folder not found exception
+	 * @return the URL file item
 	 * @throws Exception the exception
 	 */
-	public WorkspaceItem moveItem(String itemId, String destinationFolderId) throws ItemNotFoundException, WrongDestinationException, InsufficientPrivilegesException, InternalErrorException, ItemAlreadyExistException, WorkspaceFolderNotFoundException, Exception;
-
+	public URLItem createURL(String name, String description, String url, String destinationFolderId) throws Exception;
+	
 
 	/**
-	 * Change an item description.
-	 * @param itemId the item to update.
-	 * @param newDescription the new item description.
-	 * @throws ItemNotFoundException if the item has not been found.
-	 * @throws InternalErrorException if an internal error occurs.
-	 */
-	public void changeDescription(String itemId, String newDescription) throws ItemNotFoundException, InternalErrorException;
-
-
-	/**
-	 * Return the item with the specified path.
+	 * Sets the folder as public.
 	 *
-	 * @param path the item path.
-	 * @return the item.
-	 * @throws ItemNotFoundException if the item has not been found.
-	 */
-	public WorkspaceItem getItemByPath(String path) throws ItemNotFoundException;
-
-	/**
-	 * Remove an item from a folder.
-	 * @param itemName the item name.
-	 * @param folderId the folder id.
-	 * @throws ItemNotFoundException if the folder has not been found.
-	 * @throws InternalErrorException if an internal error occurs.
-	 * @throws InsufficientPrivilegesException if the user don't have sufficient privileges to perform this operation.
-	 * @throws WrongItemTypeException if the specified folder is neither a workspace nor a folder.
-	 */
-	public void remove(String itemName, String folderId) throws ItemNotFoundException, InternalErrorException, InsufficientPrivilegesException, WrongItemTypeException;
-
-	/**
-	 * Copy file.
-	 *
-	 * @param itemId the item id
-	 * @param folderDestinationId the folder destination id
-	 * @return the list
-	 * @throws ItemNotFoundException the item not found exception
-	 * @throws WrongDestinationException the wrong destination exception
-	 * @throws InternalErrorException the internal error exception
-	 * @throws ItemAlreadyExistException the item already exist exception
-	 * @throws InsufficientPrivilegesException the insufficient privileges exception
+	 * @param folderId the folder id
+	 * @param bool the bool
+	 * @return the new folder status (public or private)
 	 * @throws Exception the exception
 	 */
-	WorkspaceItem copyFile(String itemId, String folderDestinationId)
-		throws ItemNotFoundException, WrongDestinationException,
-		InternalErrorException, ItemAlreadyExistException,
-		InsufficientPrivilegesException, Exception;
-
-	/**
-	 * Copy file items.
-	 *
-	 * @param itemIds the item ids
-	 * @param folderDestinationId the folder destination id
-	 * @return the list
-	 * @throws ItemNotFoundException the item not found exception
-	 * @throws WrongDestinationException the wrong destination exception
-	 * @throws InternalErrorException the internal error exception
-	 * @throws ItemAlreadyExistException the item already exist exception
-	 * @throws InsufficientPrivilegesException the insufficient privileges exception
-	 * @throws Exception the exception
-	 */
-	List<WorkspaceItem> copyFileItems(
-		List<String> itemIds, String folderDestinationId)
-		throws ItemNotFoundException, WrongDestinationException,
-		InternalErrorException, ItemAlreadyExistException,
-		InsufficientPrivilegesException, Exception;
-
+	public boolean setFolderAsPublic(String folderId, boolean bool) throws Exception;
+	
+	
 	/**
 	 * Move items.
 	 *
@@ -531,15 +413,171 @@ public interface Workspace{
 		InsufficientPrivilegesException, InternalErrorException,
 		ItemAlreadyExistException, Exception;
 
-	/**
-	 * Search by Name.
+
+	 /**
+	 * Delete item.
 	 *
-	 * @param name the name
-	 * @param folderId the folder id
-	 * @return a list of SearchItem
+	 * @param itemId the item id
+	 * @throws ItemNotFoundException the item not found exception
 	 * @throws InternalErrorException the internal error exception
+	 * @throws InsufficientPrivilegesException the insufficient privileges exception
+	 * @throws Exception the exception
 	 */
-	public List<WorkspaceItem> searchByName(String name, String folderId) throws InternalErrorException;
+	/* Delete item.
+	 *
+	 * @param itemId the item id
+	 * @throws ItemNotFoundException the item not found exception
+	 * @throws InternalErrorException the internal error exception
+	 * @throws InsufficientPrivilegesException the insufficient privileges exception
+	 * @throws Exception the exception
+	 */
+	public void deleteItem(String itemId) throws ItemNotFoundException, InternalErrorException, InsufficientPrivilegesException, Exception;
+	
+
+	/**
+	 * Move item.
+	 *
+	 * @param itemId the item id
+	 * @param destinationFolderId the destination folder id
+	 * @return the workspace item
+	 * @throws ItemNotFoundException the item not found exception
+	 * @throws WrongDestinationException the wrong destination exception
+	 * @throws InsufficientPrivilegesException the insufficient privileges exception
+	 * @throws InternalErrorException the internal error exception
+	 * @throws ItemAlreadyExistException the item already exist exception
+	 * @throws WorkspaceFolderNotFoundException the workspace folder not found exception
+	 * @throws Exception the exception
+	 */
+	public WorkspaceItem moveItem(String itemId, String destinationFolderId) throws ItemNotFoundException, WrongDestinationException, InsufficientPrivilegesException, InternalErrorException, ItemAlreadyExistException, WorkspaceFolderNotFoundException, Exception;
+	
+	
+	/**
+	 * Copy file.
+	 *
+	 * @param itemId the item id
+	 * @param folderDestinationId the folder destination id
+	 * @return the list
+	 * @throws ItemNotFoundException the item not found exception
+	 * @throws WrongDestinationException the wrong destination exception
+	 * @throws InternalErrorException the internal error exception
+	 * @throws ItemAlreadyExistException the item already exist exception
+	 * @throws InsufficientPrivilegesException the insufficient privileges exception
+	 * @throws Exception the exception
+	 */
+	WorkspaceItem copyFile(String itemId, String folderDestinationId)
+		throws ItemNotFoundException, WrongDestinationException,
+		InternalErrorException, ItemAlreadyExistException,
+		InsufficientPrivilegesException, Exception;
+
+	
+	/**
+	 * Copy file items.
+	 *
+	 * @param itemIds the item ids
+	 * @param folderDestinationId the folder destination id
+	 * @return the list
+	 * @throws ItemNotFoundException the item not found exception
+	 * @throws WrongDestinationException the wrong destination exception
+	 * @throws InternalErrorException the internal error exception
+	 * @throws ItemAlreadyExistException the item already exist exception
+	 * @throws InsufficientPrivilegesException the insufficient privileges exception
+	 * @throws Exception the exception
+	 */
+	List<WorkspaceItem> copyFileItems(
+		List<String> itemIds, String folderDestinationId)
+		throws ItemNotFoundException, WrongDestinationException,
+		InternalErrorException, ItemAlreadyExistException,
+		InsufficientPrivilegesException, Exception;
+	
+	/**
+	 * Can user write into folder.
+	 *
+	 * @param folderId the folder id
+	 * @return true, if successful
+	 * @throws Exception the exception
+	 */
+	boolean canUserWriteIntoFolder(String folderId) throws Exception;
+
+	/*
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * TODO
+	 * 
+	 * FOLLOWING METHODS ARE NOT IMPLEMENTED;
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 * 
+	 */
+
+
+
+
+	/**
+	 * Change an item description.
+	 * @param itemId the item to update.
+	 * @param newDescription the new item description.
+	 * @throws ItemNotFoundException if the item has not been found.
+	 * @throws InternalErrorException if an internal error occurs.
+	 */
+	public void changeDescription(String itemId, String newDescription) throws ItemNotFoundException, InternalErrorException;
+
+
+
+
 
 	/**
 	 * Search By MimeType.
@@ -551,15 +589,6 @@ public interface Workspace{
 	public List<WorkspaceItem> searchByMimeType(String mimeType)
 			throws InternalErrorException;
 
-	/**
-	 * Get items by type.
-	 *
-	 * @param type the type
-	 * @return a list of SearchItem
-	 * @throws InternalErrorException the internal error exception
-	 */
-	public List<WorkspaceItem> getFolderItems(GenericItemType type) throws InternalErrorException;
-
 
 	/**
 	 * Create a shared folder with a list of users.
@@ -582,28 +611,6 @@ public interface Workspace{
 					ItemAlreadyExistException, WrongDestinationException,
 					ItemNotFoundException, WorkspaceFolderNotFoundException;
 
-	/**
-	 * Create a shared folder associated with a groupId.
-	 *
-	 * @param name the name of the folder
-	 * @param description the description
-	 * @param groupId an existing groupId to associate with the folder
-	 * @param destinationFolderId the destination folder id
-	 * @param displayName a friendly name for the folder
-	 * @param isVREFolder a flag to indicate the folder is a VRE Folder
-	 * @return the shared folder
-	 * @throws InternalErrorException the internal error exception
-	 * @throws InsufficientPrivilegesException the insufficient privileges exception
-	 * @throws ItemAlreadyExistException the item already exist exception
-	 * @throws WrongDestinationException the wrong destination exception
-	 * @throws ItemNotFoundException the item not found exception
-	 * @throws WorkspaceFolderNotFoundException the workspace folder not found exception
-	 */
-	public WorkspaceSharedFolder createSharedFolder(String name, String description,
-			String groupId, String destinationFolderId, String displayName, boolean isVREFolder)
-					throws InternalErrorException, InsufficientPrivilegesException,
-					ItemAlreadyExistException, WrongDestinationException,
-					ItemNotFoundException, WorkspaceFolderNotFoundException;
 
 	/**
 	 * Shared an exist {@link WorkspaceFolder} with a list of users.
@@ -699,23 +706,6 @@ public interface Workspace{
 			throws InternalErrorException;
 
 
-	/**
-	 * Get the disk usage of a worskpace.
-	 *
-	 * @return the disk usage
-	 * @throws InternalErrorException the internal error exception
-	 */
-	public long getDiskUsage() throws InternalErrorException;
-
-	/**
-	 * Get the total number of items in a workspace.
-	 *
-	 * @return the numer of total Items
-	 * @throws InternalErrorException the internal error exception
-	 */
-	public int getTotalItems() throws InternalErrorException;
-
-
 	/**
 	 * Removes the items.
 	 *
@@ -751,24 +741,6 @@ public interface Workspace{
 			WorkspaceFolderNotFoundException;
 
 
-	/**
-	 * Get group name by group id.
-	 *
-	 * @param groupId the group id
-	 * @return the group name
-	 * @throws InternalErrorException the internal error exception
-	 */
-	String getGroup(String groupId) throws InternalErrorException;
-
-	/**
-	 * Check if a user is a group.
-	 *
-	 * @param groupId the group id
-	 * @return true if the user is a group, false otherwise
-	 * @throws InternalErrorException the internal error exception
-	 */
-	boolean isGroup(String groupId) throws InternalErrorException;
-
 	/**
 	 * Get public folders.
 	 *
@@ -820,4 +792,6 @@ public interface Workspace{
 		throws Exception;
 
 
+
+
 }
